@@ -82,8 +82,8 @@ test_that("test deriv methods for M-splines related", {
     expect_equivalent(ms4Mat, tmp <- deriv(tmp))
     ## simple test for scale = TRUE
     csMat <- cSpline(x, knots = knots, degree = 4)
-    expect_output(str(deriv(csMat)),
-                  "matrix [1:12, 1:7]", fixed = TRUE)
+    expect_equal(isNumMatrix(deriv(csMat), 12L, 7L,
+                             warn_na = FALSE, error_na = FALSE), TRUE)
     expect_equivalent(deriv(csMat, 2), deriv(deriv(csMat)))
     expect_equivalent(deriv(csMat, 3), deriv(deriv(csMat, 2)))
     expect_equivalent(deriv(csMat, 3), deriv(deriv(deriv(csMat))))
